Orange NMF
==========

Orange NMF is an add-on for Orange_ data mining software package. It provides non-negative
matrix factorization algorithms (NMF) through NIMFA_ and robust singular value decomposition (rSVD).
It includes widgets that deal with missing data in input matrices, their normalizations, viewing and assessing
the quality of matrix factors returned by different matrix factorization algorithms.

.. _Orange: http://orange.biolab.si/

Documentation is found at:

https://orange-nmf.readthedocs.org

Widgets were designed and implemented by Fajwel Fogel (Ecole Polytechnique ParisTech). All NMF methods
call NIMFA_ library, implemented by Marinka Zitnik (Bioinformatics Laboratory, FRI UL). Thanks also to
Doug Marsteller, Stan Young (NISS), Chris Beecher, Paul Fogel.

.. _NIMFA: http://nimfa.biolab.si